@@ -8,7 +8,11 @@
 TEMPDIR=/tmp/pspp-tst-$$
 TESTFILE=$TEMPDIR/`basename $0`.sps
 
-here=`pwd`
+# ensure that top_builddir  are absolute
+if [ -z "$top_builddir" ] ; then top_builddir=. ; fi
+if [ -z "$top_srcdir" ] ; then top_srcdir=. ; fi
+top_builddir=`cd $top_builddir; pwd`
+PSPP=$top_builddir/src/ui/terminal/pspp
 
 # ensure that top_srcdir is absolute
 cd $top_srcdir ; top_srcdir=`pwd`
@@ -18,6 +22,10 @@ export STAT_CONFIG_PATH
 
 cleanup()
 {
+     if [ x"$PSPP_TEST_NO_CLEANUP" != x ] ; then 
+	echo "NOT cleaning $TEMPDIR" 
+	return ; 
+     fi
      cd /
      rm -rf $TEMPDIR
 }
@@ -69,7 +77,7 @@ if [ $? -ne 0 ] ; then no_result ; fi
 cd $TEMPDIR
 
 activity="run data"
-$SUPERVISOR $here/../src/pspp -o html $TESTFILE
+$SUPERVISOR $PSPP -o html $TESTFILE
 if [ $? -ne 0 ] ; then fail ; fi
 
 
