@@ -6,10 +6,14 @@
 TEMPDIR=/tmp/pspp-tst-$$
 TESTFILE=$TEMPDIR/`basename $0`.sps
 
-here=`pwd`;
+# ensure that top_builddir  are absolute
+if [ -z "$top_builddir" ] ; then top_builddir=. ; fi
+if [ -z "$top_srcdir" ] ; then top_srcdir=. ; fi
+top_builddir=`cd $top_builddir; pwd`
+PSPP=$top_builddir/src/ui/terminal/pspp
 
 # ensure that top_srcdir is absolute
-cd $top_srcdir; top_srcdir=`pwd`
+top_srcdir=`cd $top_srcdir; pwd`
 
 STAT_CONFIG_PATH=$top_srcdir/config
 export STAT_CONFIG_PATH
@@ -69,9 +73,27 @@ if [ $? -ne 0 ] ; then no_result ; fi
 
 # The above syntax is invalid, so this program should fail to parse
 activity="run program"
-$SUPERVISOR $here/../src/pspp --testing-mode -o raw-ascii $TESTFILE > /dev/null
+$SUPERVISOR $PSPP --testing-mode -e /dev/null $TESTFILE 
 if [ $? -ne 1 ] ; then fail ; fi
 
 
+activity="create test program 2"
+cat > $TESTFILE <<EOF
+* From bug #21108.
+input program.
+data list list /x.
+end file.
+end input program.
+
+descriptives x.
+EOF
+if [ $? -ne 0 ] ; then no_result ; fi
+
+
+# The above syntax is invalid, so this program should fail to parse
+activity="run program 2"
+$SUPERVISOR $PSPP --testing-mode -e /dev/null $TESTFILE
+if [ $? -ne 1 ] ; then fail ; fi
+
 
 pass;
