@@ -7,10 +7,14 @@
 TEMPDIR=/tmp/pspp-tst-$$
 TESTFILE=$TEMPDIR/`basename $0`.sps
 
-here=`pwd`;
+# ensure that top_builddir  are absolute
+if [ -z "$top_builddir" ] ; then top_builddir=. ; fi
+if [ -z "$top_srcdir" ] ; then top_srcdir=. ; fi
+top_builddir=`cd $top_builddir; pwd`
+PSPP=$top_builddir/src/ui/terminal/pspp
 
 # ensure that top_srcdir is absolute
-cd $top_srcdir; top_srcdir=`pwd`
+top_srcdir=`cd $top_srcdir; pwd`
 
 STAT_CONFIG_PATH=$top_srcdir/config
 export STAT_CONFIG_PATH
@@ -18,6 +22,10 @@ export STAT_CONFIG_PATH
 
 cleanup()
 {
+     if [ x"$PSPP_TEST_NO_CLEANUP" != x ] ; then 
+	echo "NOT cleaning $TEMPDIR" 
+	return ; 
+     fi
      cd /
      rm -rf $TEMPDIR
 }
@@ -74,12 +82,13 @@ if [ $? -ne 0 ] ; then no_result ; fi
 
 
 activity="run program"
-$SUPERVISOR $here/../src/pspp -o raw-ascii $TESTFILE
+$SUPERVISOR $PSPP --testing-mode $TESTFILE
 if [ $? -ne 0 ] ; then no_result ; fi
 
 activity="compare output"
-diff -B -b $TEMPDIR/pspp.list - <<EOF
-1.1 DATA LIST.  Reading free-form data from the command file.
+perl -pi -e 's/^\s*$//g' $TEMPDIR/pspp.list
+diff  -b $TEMPDIR/pspp.list - <<EOF
+1.1 DATA LIST.  Reading free-form data from INLINE.
 +--------+------+
 |Variable|Format|
 #========#======#
@@ -88,24 +97,22 @@ diff -B -b $TEMPDIR/pspp.list - <<EOF
 |DEP1    |F8.0  |
 |DEP2    |F8.0  |
 +--------+------+
-
 2.1 T-TEST.  Group Statistics
-#==========#=#====#==============#========#
-#     INDEP|N|Mean|Std. Deviation|SE. Mean#
-#==========#=#====#==============#========#
-#DEP1 a    |5|2.00|          .707|    .316#
-#     b    |5|4.00|          .707|    .316#
-#DEP2 a    |5|4.00|          .707|    .316#
-#     b    |5|2.00|          .707|    .316#
-#==========#=#====#==============#========#
-
+#=============#=#====#==============#========#
+#       INDEP |N|Mean|Std. Deviation|SE. Mean#
+#=============#=#====#==============#========#
+#DEP1 a       |5|2.00|          .707|    .316#
+#     b       |5|4.00|          .707|    .316#
+#DEP2 a       |5|4.00|          .707|    .316#
+#     b       |5|2.00|          .707|    .316#
+#=============#=#====#==============#========#
 2.2 T-TEST.  Independent Samples Test
 #===============================#==========#===============================================================================#
 #                               # Levene's |                          t-test for Equality of Means                         #
 #                               #----+-----+------+-----+---------------+---------------+---------------------+------------#
-#                               #    |     |      |     |               |               |                     |    95%     #
+#                               #    |     |      |     |               |               |                     |     95%    #
 #                               #    |     |      |     |               |               |                     +------+-----#
-#                               # F  | Sig.|   t  |  df |Sig. (2-tailed)|Mean Difference|Std. Error Difference| Lower|Upper#
+#                               #  F | Sig.|   t  |  df |Sig. (2-tailed)|Mean Difference|Std. Error Difference| Lower|Upper#
 #===============================#====#=====#======#=====#===============#===============#=====================#======#=====#
 #DEP1Equal variances assumed    #.000|1.000|-4.472|    8|           .002|         -2.000|                 .447|-3.031|-.969#
 #    Equal variances not assumed#    |     |-4.472|8.000|           .002|         -2.000|                 .447|-3.031|-.969#
