@@ -5,10 +5,14 @@
 TEMPDIR=/tmp/pspp-tst-$$
 TESTFILE=$TEMPDIR/`basename $0`.sps
 
-here=`pwd`;
+# ensure that top_builddir  are absolute
+if [ -z "$top_builddir" ] ; then top_builddir=. ; fi
+if [ -z "$top_srcdir" ] ; then top_srcdir=. ; fi
+top_builddir=`cd $top_builddir; pwd`
+PSPP=$top_builddir/src/ui/terminal/pspp
 
 # ensure that top_srcdir is absolute
-cd $top_srcdir; top_srcdir=`pwd`
+top_srcdir=`cd $top_srcdir; pwd`
 
 STAT_CONFIG_PATH=$top_srcdir/config
 export STAT_CONFIG_PATH
@@ -16,6 +20,10 @@ export STAT_CONFIG_PATH
 
 cleanup()
 {
+     if [ x"$PSPP_TEST_NO_CLEANUP" != x ] ; then 
+	echo "NOT cleaning $TEMPDIR" 
+	return ; 
+     fi
      cd /
      rm -rf $TEMPDIR
 }
@@ -60,8 +68,9 @@ end data.
 
 list.
 
-data list free/A B C D.
+data list free skip=1/A B C D.
 begin data.
+# This record is ignored.
 ,1,2,3
 ,4,,5
 6
@@ -77,8 +86,10 @@ begin data.
 end data.
 list.
 
-data list free (tab)/A B C D.
+data list free (tab) skip=2/A B C D.
 begin data.
+# These records
+# are skipped.
 1	2	3	4
 1	2	3	
 1	2		4
@@ -95,6 +106,40 @@ begin data.
 		3	
 			4
 			
+end data.
+list.
+
+* Test DATA LIST FIXED with multiple records.
+data list fixed notable
+	/1 start 1-20 (adate)
+	/2 end 1-20 (adate)
+	/3 count 1-3.
+begin data.
+07-22-2007
+10-06-2007
+321
+07-14-1789
+08-26-1789
+4
+01-01-1972
+12-31-1999
+682
+end data.
+list.
+
+* Test that DATA LIST FIXED works with an empty trailing record.
+data list fixed notable records=2/x 1 y 2.
+begin data.
+12
+
+34
+
+56
+
+78
+
+90
+
 end data.
 list.
 EOF
@@ -102,12 +147,13 @@ if [ $? -ne 0 ] ; then no_result ; fi
 
 
 activity="run program"
-$SUPERVISOR $here/../src/pspp --testing-mode -o raw-ascii --testing-mode $TESTFILE
+$SUPERVISOR $PSPP --testing-mode $TESTFILE
 if [ $? -ne 0 ] ; then fail ; fi
 
 activity="compare output"
-diff -b -B $TEMPDIR/pspp.list - << EOF
-1.1 DATA LIST.  Reading free-form data from the command file.
+perl -pi -e 's/^\s*$//g' $TEMPDIR/pspp.list
+diff -b  $TEMPDIR/pspp.list - << EOF
+1.1 DATA LIST.  Reading free-form data from INLINE.
 +--------+------+
 |Variable|Format|
 #========#======#
@@ -116,13 +162,11 @@ diff -b -B $TEMPDIR/pspp.list - << EOF
 |C       |F8.0  |
 |D       |F8.0  |
 +--------+------+
-
        A        B        C        D
 -------- -------- -------- --------
     1.00    23.00    45.00     2.03 
     2.00    22.00    34.00    23.00 
     3.00    34.00    34.00    34.00 
-
        A        B        C        D
 -------- -------- -------- --------
      .       1.00     2.00     3.00 
@@ -131,7 +175,6 @@ diff -b -B $TEMPDIR/pspp.list - << EOF
      .00     1.00      .        .   
      .        .        .        .   
     2.00     3.00     4.00     5.00 
-
        A        B        C        D
 -------- -------- -------- --------
     1.00     2.00     3.00     4.00 
@@ -150,6 +193,18 @@ diff -b -B $TEMPDIR/pspp.list - << EOF
      .        .       3.00      .   
      .        .        .       4.00 
      .        .        .        .   
+               start                  end count
+-------------------- -------------------- -----
+          07/22/2007           10/06/2007   321
+          07/14/1789           08/26/1789     4
+          01/01/1972           12/31/1999   682
+x y
+- -
+1 2
+3 4
+5 6
+7 8
+9 0
 EOF
 if [ $? -ne 0 ] ; then fail ; fi
 
