@@ -5,10 +5,14 @@
 TEMPDIR=/tmp/pspp-tst-$$
 TESTFILE=$TEMPDIR/`basename $0`.sps
 
-here=`pwd`;
+# ensure that top_builddir  are absolute
+if [ -z "$top_builddir" ] ; then top_builddir=. ; fi
+if [ -z "$top_srcdir" ] ; then top_srcdir=. ; fi
+top_builddir=`cd $top_builddir; pwd`
+PSPP=$top_builddir/src/ui/terminal/pspp
 
 # ensure that top_srcdir is absolute
-cd $top_srcdir; top_srcdir=`pwd`
+top_srcdir=`cd $top_srcdir; pwd`
 
 STAT_CONFIG_PATH=$top_srcdir/config
 export STAT_CONFIG_PATH
@@ -16,6 +20,10 @@ export STAT_CONFIG_PATH
 
 cleanup()
 {
+     if [ x"$PSPP_TEST_NO_CLEANUP" != x ] ; then 
+	echo "NOT cleaning $TEMPDIR" 
+	return ; 
+     fi
      cd /
      rm -rf $TEMPDIR
 }
@@ -78,12 +86,13 @@ if [ $? -ne 0 ] ; then no_result ; fi
 
 
 activity="run program"
-$SUPERVISOR $here/../src/pspp --testing-mode -o raw-ascii $TESTFILE
+$SUPERVISOR $PSPP --testing-mode $TESTFILE
 if [ $? -ne 0 ] ; then no_result ; fi
 
 
 activity="check results"
-diff -B -b $TEMPDIR/pspp.list - << EOF
+perl -pi -e 's/^\s*$//g' $TEMPDIR/pspp.list
+diff  -b $TEMPDIR/pspp.list - << EOF
  X FILTER_$
 -- --------
  1     1.00 
@@ -91,7 +100,6 @@ diff -B -b $TEMPDIR/pspp.list - << EOF
  5     1.00 
  7     1.00 
  9     1.00 
-
  X FILTER_$
 -- --------
  1     1.00 
@@ -104,7 +112,6 @@ diff -B -b $TEMPDIR/pspp.list - << EOF
  8      .00 
  9     1.00 
 10      .00 
-
  X FILTER_$
 -- --------
  2     1.00 
@@ -112,7 +119,6 @@ diff -B -b $TEMPDIR/pspp.list - << EOF
  6     1.00 
  8     1.00 
 10     1.00 
-
 EOF
 if [ $? -ne 0 ] ; then fail ; fi
 
